==> u61-1.0.1.tar.gz: u61-1.0.1/src/utils.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   utils.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: contains some global "utils type" function such as custom
 *              random functions for instance
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <stdlib.h>
#include <ClanLib/display.h>

#include "utils.h"
#include "debug.h"

/*---------------------------------------------------------------------------
 variants
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * returns a random number between 0 and scale-1
 */
int U61_Utils::random(int scale)
{
  int temp;

#ifdef U61_MSVC
  temp=rand();
#else
  temp=::random();
#endif

  if (temp<0)
    {
      temp=-temp;
    }

  return (temp%scale);
}

/*--------------------------------------------------------------------------*/
/*
 * Sets a videomode
 * This function simply calls ClanLib's set_videomode function with several
 * parameters, so that it only fails in critical cases
 */
bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
{
  bool ok=false;
  char *requested_mode="";
  char *alternate_mode="";

  if (fullscreen)
    {
      requested_mode="fullscreen";
      alternate_mode="windowed";
    }
  else
    {
      requested_mode="windowed";
      alternate_mode="fullscreen";      
    }

  if (!ok)
    {
      try 
	{
	  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<requested_mode<<"\".");
	  CL_Display::set_videomode(w,h,16,fullscreen);
	  ok=true;
	}
      catch (CL_Error e)
	{
          try
	    {
	      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<alternate_mode<<"\".");
	      CL_Display::set_videomode(w,h,16,!fullscreen);
	      ok=true;
	    }
	  catch (CL_Error e)
	    {
	      try
		{
		  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<requested_mode<<"\".");
		  CL_Display::set_videomode(w,h,8,fullscreen);
		  ok=true;
		}
	      catch (CL_Error e)
		{
		  try
		    {
		      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<alternate_mode<<"\".");
		      CL_Display::set_videomode(w,h,8,!fullscreen);
		      ok=true;
		    }
		  catch (CL_Error e)
		    {
		      U61_LOG_WARNING("Unable to set up a valid video mode");
		    }
		}
	    }
	}
    }

  return ok;
}

/*--------------------------------------------------------------------------*/
/*
 * Returns true if the file exists
 */
bool U61_Utils::file_exists(char *filename)
{
  FILE *f;
  bool exists=false;

  f=fopen(filename,"r");
  
  if (f!=NULL)
    {
      exists=true;
      fclose(f);
    }
  
  return exists;
}

==> u61-1.1.0.tar.gz: u61-1.1.0/src/utils.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000-2003 Christian Mauduit (ufoot@ufoot.org)              *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on Savannah (http://savannah.gnu.org)     *
 ****************************************************************************/

/*
 * file name:   utils.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: contains some global "utils type" function such as custom
 *              random functions for instance
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <stdlib.h>
#include <ClanLib/display.h>

#include "utils.h"
#include "log.h"
#include "mouse.h"
#include "macro.h"

/*---------------------------------------------------------------------------
 variants
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * returns a random number between 0 and scale-1
 */
int U61_Utils::random(int scale)
{
  int temp;

#ifdef U61_DEF_MSVC
  temp=rand();
#else
  temp=::random();
#endif

  if (temp<0)
    {
      temp=-temp;
    }

  return (temp%scale);
}

/*--------------------------------------------------------------------------*/
/*
 * Sets a videomode
 * This function simply calls ClanLib's set_videomode function with several
 * parameters, so that it only fails in critical cases
 */
bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
{
  bool ok=false;
  char *requested_mode="";
  char *alternate_mode="";

  if (fullscreen)
    {
      requested_mode="fullscreen";
      alternate_mode="windowed";
    }
  else
    {
      requested_mode="windowed";
      alternate_mode="fullscreen";      
    }

  if (!ok)
    {
      try 
	{
	  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<requested_mode<<"\".");
	  CL_Display::set_videomode(w,h,16,fullscreen);
	  ok=true;
	}
      catch (CL_Error e)
	{
          try
	    {
	      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<alternate_mode<<"\".");
	      CL_Display::set_videomode(w,h,16,!fullscreen);
	      ok=true;
	    }
	  catch (CL_Error e)
	    {
	      try
		{
		  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<requested_mode<<"\".");
		  CL_Display::set_videomode(w,h,8,fullscreen);
		  ok=true;
		}
	      catch (CL_Error e)
		{
		  try
		    {
		      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<alternate_mode<<"\".");
		      CL_Display::set_videomode(w,h,8,!fullscreen);
		      ok=true;
		    }
		  catch (CL_Error e)
		    {
		      U61_LOG_WARNING("Unable to set up a valid video mode");
		    }
		}
	    }
	}
    }

  if (ok)
    {
      U61_Mouse::hide();
    }

  return ok;
}

/*--------------------------------------------------------------------------*/
/*
 * Returns true if the file exists
 */
bool U61_Utils::file_exists(char *filename)
{
  FILE *f;
  bool exists=false;

  f=fopen(filename,"r");
  
  if (f!=NULL)
    {
      exists=true;
      fclose(f);
    }
  
  return exists;
}

/*--------------------------------------------------------------------------*/
/*
 * Converts a binary buffer to its hexadecimal ascii representation.
 * Usefull for logging and displaying binary datas.
 * hexascii_data must be at least 2*binary_data_size+1 bytes
 */
void U61_Utils::to_hexascii(char *hexascii_data,
			    unsigned char *binary_data, 
			    int binary_data_size)
{
  int i;
  unsigned char c;
  unsigned int hex;
  char *buf;

  for (i=0;i<binary_data_size;++i)
    {
      c=binary_data[i];
      hex=c;
      buf=hexascii_data+i*2;

      U61_MACRO_SNPRINTF1(buf,3,"%02x",hex);
    }

  hexascii_data[binary_data_size*2]='\0';
}
